==> cantata_2.5.3.orig.tar.gz: cantata-2.5.3/3rdparty/solid-lite/backends/wmi/wmiportablemediaplayer.h <==
/*
    Copyright 2006 Davide Bettio <davide.bettio@kdemail.net>
    Copyright 2007 Jeff Mitchell <kde-dev@emailgoeshere.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_WMI_PORTABLEMEDIAPLAYER_H
#define SOLID_BACKENDS_WMI_PORTABLEMEDIAPLAYER_H

#include <solid-lite/ifaces/portablemediaplayer.h>
#include "wmideviceinterface.h"

#include <QStringList>

namespace Solid
{
namespace Backends
{
namespace Wmi
{
class WmiDevice;

class PortableMediaPlayer : public DeviceInterface, virtual public Solid::Ifaces::PortableMediaPlayer
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::PortableMediaPlayer)

public:
    PortableMediaPlayer(WmiDevice *device);
    virtual ~PortableMediaPlayer();

    virtual QStringList supportedProtocols() const;
    virtual QStringList supportedDrivers(QString protocol = QString()) const;
    virtual QVariant driverHandle(const QString &driver) const;
};
}
}
}

#endif // SOLID_BACKENDS_WMI_PORTABLEMEDIAPLAYER_H

==> cantata-3.3.1.tar.gz: cantata-3.3.1/3rdparty/solid-lite/backends/wmi/wmiportablemediaplayer.h <==
/*
    Copyright 2006 Davide Bettio <davide.bettio@kdemail.net>
    Copyright 2007 Jeff Mitchell <kde-dev@emailgoeshere.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_WMI_PORTABLEMEDIAPLAYER_H
#define SOLID_BACKENDS_WMI_PORTABLEMEDIAPLAYER_H

#include "wmideviceinterface.h"
#include <solid-lite/ifaces/portablemediaplayer.h>

#include <QStringList>

namespace Solid {
namespace Backends {
namespace Wmi {
class WmiDevice;

class PortableMediaPlayer : public DeviceInterface, virtual public Solid::Ifaces::PortableMediaPlayer {
	Q_OBJECT
	Q_INTERFACES(Solid::Ifaces::PortableMediaPlayer)

public:
	PortableMediaPlayer(WmiDevice* device);
	virtual ~PortableMediaPlayer();

	virtual QStringList supportedProtocols() const;
	virtual QStringList supportedDrivers(QString protocol = QString()) const;
	virtual QVariant driverHandle(const QString& driver) const;
};
}// namespace Wmi
}// namespace Backends
}// namespace Solid

#endif// SOLID_BACKENDS_WMI_PORTABLEMEDIAPLAYER_H
